@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.92';
+  $CPAN::Perl::Releases::VERSION = '0.96';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -339,6 +339,14 @@ our $data =
     "tar.bz2" => "D/DR/DROLSKY/perl-5.17.7.tar.bz2",
     "tar.gz" => "D/DR/DROLSKY/perl-5.17.7.tar.gz",
   },
+  "5.17.8" => {
+    "tar.bz2" => "A/AR/ARC/perl-5.17.8.tar.bz2",
+    "tar.gz" => "A/AR/ARC/perl-5.17.8.tar.gz",
+  },
+  "5.17.9" => {
+    "tar.bz2" => "B/BI/BINGOS/perl-5.17.9.tar.bz2",
+    "tar.gz" => "B/BI/BINGOS/perl-5.17.9.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -447,7 +455,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.92
+version 0.96
 
 =head1 SYNOPSIS
 
@@ -503,7 +511,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Chris Williams.
+This software is copyright (c) 2013 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
